@@ -152,25 +152,21 @@ def startOps(ops):
     datesHist.append(sim_dates[0])
     return dbars
 
+def getDeltaOrder(req):
+    vol=req['volume']
 
+    if req['type']==mt5.ORDER_TYPE_SELL_LIMIT or req['type']==mt5.ORDER_TYPE_SELL:
+        vol=-vol    
+    #elif req['type']==mt5.ORDER_TYPE_BUY_LIMIT or req['type']==mt5.ORDER_TYPE_BUY:
+    #    return False
+    return vol
 
 def executeOrders(orders,ops,dbars):
     assets=ops['assets']
     total_in_shares=0.0
     sim_dates.append(getCurrTime(ops))
-    # No orders!
-    if orders==None:
-        equityHist.append(equityHist[-1])
-        balanceHist.append(balanceHist[-1])
-        datesHist.append(sim_dates[-1])
-        balance=b3.getBalance() 
-        total_in_shares=b3.getPosition()
-        if ops['verbose']:
-            print( 'No orders in time(',sim_dates[-1],') = ',sim_dates[-1],' balance=',balance, 'total in shares=',total_in_shares,' Positon=',(balance+total_in_shares))
-        return True
-    #Yes, some orders
-    if ops['verbose']:
-        print('List of ',len(orders),'orders in time(',sim_dates[-1],') :')
+
+    txt=''
     for asset in assets:
         order=getOrder(orders,asset)
         # send order
@@ -179,19 +175,23 @@ def executeOrders(orders,ops,dbars):
                     print('order sent to B3')
             else:
                     print('Error  : ',b3.getLastError())
+            txt=txt+' '+asset+', '+ str(shares)+', '+str(getDeltaOrder(order))+';'
         else:
             balance=b3.getBalance() 
             shares=b3.getShares(asset)
-            print("No order at the moment for asset=",asset,' balance=',balance,' asset''s shares=',shares)
+            txt=txt+' '+asset+','+ str(shares)+', 0;'
             continue
     balance=b3.getBalance() 
     total_in_shares=b3.getPosition()
-    if ops['verbose']:
-        print( len(orders),' order(s) in time(',sim_dates[-1],' capital=',balance, 'total in shares=',total_in_shares, 'equity=',balance+total_in_shares)
+    if ops['verbose']==True:
+        msg=str(len(orders))+' order(s) in time('+str(sim_dates[-1])+' equity={:,.2f} balance={:,.2f} '+txt
+        print(msg.format(balance+total_in_shares,balance))
+    else:
+        print(len(orders),' order(s) in time(',sim_dates[-1],'). Use verbose=True for more information')
     equityHist.append(balance+total_in_shares)
     balanceHist.append(balance)
     datesHist.append(sim_dates[-1])
-    #detalhamento das ordens
+    
     
     
 
